@@ -133,14 +133,6 @@ typedef enum {
 	FU_CPU_VENDOR_LAST
 } FuCpuVendor;
 
-/**
- * FU_BATTERY_VALUE_INVALID:
- *
- * This value signifies the battery level is either unset, or the value cannot
- * be discovered.
- */
-#define FU_BATTERY_VALUE_INVALID 101
-
 /**
  * FuBatteryState:
  * @FU_BATTERY_STATE_UNKNOWN:		Unknown
