@@ -33,6 +33,8 @@ struct _FuUdevDeviceClass {
  * @FU_UDEV_DEVICE_FLAG_VENDOR_FROM_PARENT:	Get the vendor ID fallback from the parent
  * @FU_UDEV_DEVICE_FLAG_USE_CONFIG:		Read and write from the device config
  * @FU_UDEV_DEVICE_FLAG_OPEN_NONBLOCK:		Open nonblocking, e.g. O_NONBLOCK
+ * @FU_UDEV_DEVICE_FLAG_OPEN_SYNC:		Open sync, e.g. O_SYNC
+ * @FU_UDEV_DEVICE_FLAG_IOCTL_RETRY:		Retry the ioctl() call when required
  *
  * Flags used when opening the device using fu_device_open().
  **/
@@ -43,6 +45,8 @@ typedef enum {
 	FU_UDEV_DEVICE_FLAG_VENDOR_FROM_PARENT = 1 << 2,
 	FU_UDEV_DEVICE_FLAG_USE_CONFIG = 1 << 3,
 	FU_UDEV_DEVICE_FLAG_OPEN_NONBLOCK = 1 << 4,
+	FU_UDEV_DEVICE_FLAG_OPEN_SYNC = 1 << 5,
+	FU_UDEV_DEVICE_FLAG_IOCTL_RETRY = 1 << 6,
 	/*< private >*/
 	FU_UDEV_DEVICE_FLAG_LAST
 } FuUdevDeviceFlags;
@@ -62,6 +66,10 @@ fu_udev_device_get_sysfs_path(FuUdevDevice *self);
 const gchar *
 fu_udev_device_get_subsystem(FuUdevDevice *self);
 const gchar *
+fu_udev_device_get_bind_id(FuUdevDevice *self);
+void
+fu_udev_device_set_bind_id(FuUdevDevice *self, const gchar *bind_id);
+const gchar *
 fu_udev_device_get_driver(FuUdevDevice *self);
 guint32
 fu_udev_device_get_vendor(FuUdevDevice *self);
@@ -96,6 +104,13 @@ gboolean
 fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc, GError **error)
     G_GNUC_WARN_UNUSED_RESULT;
 gboolean
+fu_udev_device_ioctl_full(FuUdevDevice *self,
+			  gulong request,
+			  guint8 *buf,
+			  gint *rc,
+			  guint timeout,
+			  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
 fu_udev_device_pwrite(FuUdevDevice *self, goffset port, guint8 data, GError **error)
     G_GNUC_WARN_UNUSED_RESULT;
 gboolean
@@ -113,8 +128,15 @@ fu_udev_device_pread_full(FuUdevDevice *self,
 			  guint8 *buf,
 			  gsize bufsz,
 			  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fu_udev_device_seek(FuUdevDevice *self, goffset offset, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 const gchar *
 fu_udev_device_get_sysfs_attr(FuUdevDevice *self, const gchar *attr, GError **error);
+gboolean
+fu_udev_device_get_sysfs_attr_uint64(FuUdevDevice *self,
+				     const gchar *attr,
+				     guint64 *value,
+				     GError **error);
 gchar *
 fu_udev_device_get_parent_name(FuUdevDevice *self);
 
@@ -129,3 +151,5 @@ GPtrArray *
 fu_udev_device_get_siblings_with_subsystem(FuUdevDevice *self, const gchar *subsystem);
 GPtrArray *
 fu_udev_device_get_children_with_subsystem(FuUdevDevice *self, const gchar *subsystem);
+FuUdevDevice *
+fu_udev_device_get_parent_with_subsystem(FuUdevDevice *self, const gchar *subsystem);
